@@ -311,6 +311,10 @@ ags_synth_init(AgsSynth *synth)
 void
 ags_synth_finalize(GObject *gobject)
 {
+  g_hash_table_remove(ags_machine_generic_output_message_monitor,
+		      gobject);
+
+  /* call parent */
   G_OBJECT_CLASS(ags_synth_parent_class)->finalize(gobject);
 }
 
